@@ -1,5 +1,10 @@
 package P5U::Command;
 
+BEGIN {
+	$P5U::Command::AUTHORITY = 'cpan:TOBYINK';
+	$P5U::Command::VERSION   = '0.100';
+};
+
 use 5.010;
 use strict;
 use App::Cmd::Setup-command;
@@ -7,32 +12,32 @@ use App::Cmd::Setup-command;
 use File::HomeDir qw<>;
 use File::Temp qw<>;
 use JSON qw<>;
-use Path::Class qw<>;
+use Path::Tiny qw<>;
 use Object::AUTHORITY;
 
 my %config;
 
 sub get_tempdir
 {
-	Path::Class::Dir::->new(File::Temp::->newdir);
+	Path::Tiny::->tempdir;
 }
 
 sub _get_distdatadir
 {
 	File::HomeDir::->my_dist_data('P5U') //
-	Path::Class::Dir::->new(File::HomeDir::->my_home => qw(perl5 utils data))->stringify
+	Path::Tiny::->new(File::HomeDir::->my_home => qw(perl5 utils data))->stringify
 }
 
 sub _get_distconfigdir
 {
 	File::HomeDir::->my_dist_data('P5U') //
-	Path::Class::Dir::->new(File::HomeDir::->my_home => qw(perl5 utils etc))->stringify
+	Path::Tiny::->new(File::HomeDir::->my_home => qw(perl5 utils etc))->stringify
 }
 
 sub get_cachedir
 {
 	my $self = shift;
-	my $d = Path::Class::Dir::->new(
+	my $d = Path::Tiny::->new(
 		$self->_get_distdatadir,
 		(($self->command_names)[0]),
 		'cache',
@@ -44,7 +49,7 @@ sub get_cachedir
 sub get_datadir
 {
 	my $self = shift;
-	my $d = Path::Class::Dir::->new(
+	my $d = Path::Tiny::->new(
 		$self->_get_distdatadir,
 		(($self->command_names)[0]),
 		'store',
@@ -56,7 +61,7 @@ sub get_datadir
 sub get_configfile
 {
 	my $self = shift;
-	my $f = Path::Class::File::->new(
+	my $f = Path::Tiny::->new(
 		$self->_get_distconfigdir,
 		(($self->command_names)[0]),
 		'config.json',
